@@ -5,6 +5,8 @@
 import linked_list_mod
 
 class Lifo(object):
+    # pylint: disable=incomplete-protocol
+
     '''A LIFO (stack), implemented over Linked_list'''
 
     def __init__(self):
@@ -28,3 +30,14 @@ class Lifo(object):
         else:
             raise IndexError('LIFO empty')
 
+    def __len__(self):
+        return len(self.linked_list)
+
+    def __bool__(self):
+        '''Return True iff we are nonempty'''
+        if self.linked_list:
+            return True
+        else:
+            return False
+
+    __nonzero__ = __bool__
